Skip to contents

Returns the range of years for which enrollment data can be fetched from the Illinois State Board of Education.

Usage

get_available_years()

Value

A list with components:

min_year

Earliest available year (1997)

max_year

Most recent available year (2024)

description

Human-readable description of the date range

Examples

get_available_years()
#> $min_year
#> [1] 1997
#> 
#> $max_year
#> [1] 2024
#> 
#> $description
#> [1] "Illinois enrollment data is available from 1997 to 2024"
#>